@@ -49,7 +49,9 @@ test_that("WSAF Related", {
     dev.off()
     expect_that(inherits(plotHistWSAFPlotly(obsWSAF), "plotly"), is_true())
     p <- plotHistWSAFPlotly(obsWSAF)
-    htmlwidgets::saveWidget(p, file = "histWSAFPlotly.html")
+    if (htmlwidgets:::pandoc_available()){
+        htmlwidgets::saveWidget(p, file = "histWSAFPlotly.html")
+    }
     expect_null(plotWSAFvsPLAF(plaf, obsWSAF))
     png("WSAFvsPLAF.png")
     plotWSAFvsPLAF(plaf, obsWSAF)
@@ -62,7 +64,9 @@ test_that("WSAF Related", {
     p <- plotWSAFVsPLAFPlotly(plaf, obsWSAF,
                               PG0390CoverageVcf$refCount,
                               PG0390CoverageVcf$altCount)
-    htmlwidgets::saveWidget(p, file = "WSAFvsPLAFPlotly.html")
+    if (htmlwidgets:::pandoc_available()){
+        htmlwidgets::saveWidget(p, file = "WSAFvsPLAFPlotly.html")
+    }
     expect_null(plotObsExpWSAF(obsWSAF, expWSAF))
     png("ObsExpWSAF.png")
     plotObsExpWSAF(obsWSAF, expWSAF)
@@ -70,7 +74,9 @@ test_that("WSAF Related", {
     expect_that(inherits(plotObsExpWSAFPlotly(obsWSAF, expWSAF),
                          "plotly"), is_true())
     p <- plotObsExpWSAFPlotly(obsWSAF, expWSAF)
-    htmlwidgets::saveWidget(p, file = "ObsExpWSAFPlotly.html")
+    if (htmlwidgets:::pandoc_available()){
+        htmlwidgets::saveWidget(p, file = "ObsExpWSAFPlotly.html")
+    }
 })
 
 
@@ -85,7 +91,9 @@ test_that("plotAltVsRef", {
                          "plotly"), is_true())
     p <- plotAltVsRefPlotly(PG0390CoverageVcf$refCount,
                             PG0390CoverageVcf$altCount)
-    htmlwidgets::saveWidget(p, file = "plotAltVsRefPlotly.html")
+    if (htmlwidgets:::pandoc_available()){
+        htmlwidgets::saveWidget(p, file = "plotAltVsRefPlotly.html")
+    }
 })
 
 
